/*
 * Copyright 2004 Perforce Software.  All rights reserved.
 *
 * Developed by Data Shades Ltd.
 */

#ifndef INC_ABOUT_DIALOG
#define INC_ABOUT_DIALOG

#include "Dialog.h"
#include "PerforceAPI.h"
#include "UniStrBuf.h"

/*
 * AboutDialog - show the About dialog box.
 */

class AboutDialog : public Dialog {

public:

	/*
	 * Constructor
	 *
	 * ops - The plugin operations object.
	 * name - Plugin name.
	 * pluginVer - Version of plugin.
	 * appVer - Version of host application.
	 */

							AboutDialog( PluginOperations *ops, TCHAR *name, TCHAR *pluginVer, TCHAR *appVer );

	/*
	 * Get host application version
	 */
	TCHAR					*AppVersion() { return appVersion; };

	/*
	 * Get name of plugin
	 */
	TCHAR					*PluginName() { return pluginName; }; 

	/*
	 * Get plugin version
	 */
	TCHAR					*PluginVersion() { return pluginVersion; };


private:
	
	/* 
	 * Dialog windows procedure
	 *
	 * hWnd - Handle of dialog window.
	 * uMsg - Windows message.
	 * wParam - Message wParam.
	 * lParam - Message lParam.
	 */
	static INT_PTR CALLBACK	DialogWndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam );

	/*
	 * Get the windows version string. Returns TRUE if successful
	 *
	 * buff - buffer to return version string
	 */
	bool					WindowsVersion( UniStrBuf &buff );

	/* 
	 * Name of plugin 
	 */
	TCHAR					*pluginName;

	/* 
	 * Version of plugin 
	 */
	TCHAR					*pluginVersion;

	/* 
	 * Version of host application 
	 */
	TCHAR					*appVersion;
};

#endif